@@ -8,6 +8,7 @@ from making_with_code_cli.styles import (
     confirm,
     info,
     success,
+    warn,
     error,
 )
 import click
@@ -28,15 +29,19 @@ INTRO_NOTES = [
     "The setup may ask for your password. As a security measure, you won't see any characters when you type it in.",
     "If you get stuck or have any questions, ask a teacher.",
 ]
+WORK_DIR_PERMISSIONS = S_IRWXU | S_IXGRP | S_IXOTH
 
 class Platform(Flag):
     MAC = auto()
     LINUX = auto()
-    SUPPORTED = MAC | LINUX
+    WSL = auto()
+    SUPPORTED = MAC | LINUX | WSL
     UNSUPPORTED = 0
 
     @classmethod
     def detect(self):
+        if Path("/proc/version").exists() and "WSL" in Path("/proc/version").read_text():
+            return self.WSL
         if sys.platform.startswith("darwin"):
             return self.MAC
         if sys.platform.startswith("linux"):
@@ -49,8 +54,6 @@ def default_work_dir():
     else:
         return Path.home() / "making_with_code"
 
-WORK_DIR_PERMISSIONS = S_IRWXU | S_IXGRP | S_IXOTH
-
 def choose_mwc_username(default=None):
     """Asks the user to choose their MWC username."""
     click.prompt(
@@ -122,7 +125,7 @@ def choose_editor(default=None):
             question("Which code editor do you want to use?"),
             default=default
         )
-        if editor_installed(ed) or ed in ['subl']:
+        if editor_installed(ed) or ed in ['subl', 'charm']:
             return ed
         click.echo(error(f"Couldn't find {ed}. Double-check that it's installed."))
 
@@ -202,14 +205,14 @@ class InstallHomebrew(SetupTask):
     def run_task(self):
         click.echo(address("Installing homebrew... (this may take a while)"))
         cmd = '/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh)"'
-        run(cmd, shell=True)
+        run(cmd, shell=True, check=True)
 
 class InstallXCode(SetupTask):
     description = "Install XCode"
     platform = Platform.MAC
 
     def is_complete(self):
-        return bool(run("xcode-select -p", shell=True, capture_output=True).stdout)
+        return bool(run("xcode-select -p", shell=True, capture_output=True, check=True).stdout)
 
     def run_task(self):
         msg = (
@@ -217,7 +220,7 @@ class InstallXCode(SetupTask):
             "Please click \"Install\" and accept the license agreement. "
         )
         click.echo(address(msg))
-        run("xcode-select --install", shell=True)
+        run("xcode-select --install", shell=True, check=True)
 
 class InstallPoetry(SetupTask):
     description = "Install poetry"
@@ -228,12 +231,12 @@ class InstallPoetry(SetupTask):
     def run_task(self):
         shell = get_shell_name()
         click.echo(address("Installing poetry..."))
-        run("curl -sSL https://install.python-poetry.org | python3 -", shell=True)
+        run("curl -sSL https://install.python-poetry.org | python3 -", shell=True, check=True)
         click.echo(address("Installing poetry tab completions..."))
         if shell == "bash":
-            run("poetry completions bash > /etc/bash_completion.d/poetry", shell=True)
+            run("poetry completions bash > /etc/bash_completion.d/poetry", shell=True, check=True)
         if shell == "zsh":
-            run("poetry completions zsh > ~/.zfunc/_poetry")
+            run("poetry completions zsh > ~/.zfunc/_poetry", shell=True, check=True)
 
 class WriteShellConfig(SetupTask):
     description = "Write the MWC shell configuration file ~/.mwc_rc"
@@ -248,10 +251,18 @@ class WriteShellConfig(SetupTask):
             fh.write("# Making With Code RC File\n\n")
             fh.write("## Add Poetry to $PATH\n")
             fh.write('export PATH="$HOME/.local/bin:$PATH"\n\n')
-            if Platform.detect() == Platform.MAC and self.settings['editor'] == "subl":
-                fh.write("## Add subl to $PATH\n")
-                fh.write('export PATH="/Applications/Sublime Text.app/Contents/SharedSupport/bin:$PATH"\n\n')
-        run(f"source {get_mwc_rc_path()}", shell=True)
+            if Platform.detect() == Platform.MAC:
+                if self.settings['editor'] == "subl":
+                    fh.write("## Add subl to $PATH\n")
+                    fh.write('export PATH="/Applications/Sublime Text.app/Contents/SharedSupport/bin:$PATH"\n\n')
+            if Platform.detect() == Platform.WSL:
+                if self.settings['editor'] == "subl":
+                    fh.write("## Create subl alias for Sublime Text\n")
+                    fh.write('alias subl=\'"/mnt/c/Program Files/Sublime Text 3/subl.exe"\'')
+                if self.settings['editor'] == "atom":
+                    fh.write("## Create atom alias\n")
+                    fh.write('alias atom=”/mnt/c/Windows/System32/cmd.exe /c \'atom\'"\n\n')
+        run(f"source {get_mwc_rc_path()}", shell=True, check=True)
 
 class InstallPackage(SetupTask):
     package_name = "package"
@@ -269,7 +280,7 @@ class InstallPackage(SetupTask):
         platform = Platform.detect()
         click.echo(address(f"Installing {self.package_name}..."))
         pkg = self.brew_name if (platform == Platform.MAC) else self.apt_name
-        run(f"{self.package_installer()} install {pkg}", shell=True)
+        run(f"{self.package_installer()} install {pkg}", shell=True, check=True)
 
     def package_installer(self):
         platform = Platform.detect()
@@ -304,7 +315,7 @@ class GHAuthentication(SetupTask):
 
     def run_task(self):
         click.echo(address("You will now be prompted to log in to github.com (or to create an account)."))
-        run("gh auth login", shell=True)
+        run("gh auth login", shell=True, check=True)
 
     def gh_auth_data(self):
         if self.gh_auth_file.exists():
